<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

if ( ! function_exists( 'yule_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Yule Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yule_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'yule_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'yule_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Yule Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yule_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'yule_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Home Page Active Callbacks
 */
/**
 * Check if top bar contact is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_top_bar_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[top_bar_enable]' )->value() );
}

/**
 * Check if popular is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular content type is page.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_popular_section_content_page( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[popular_content_type]' )->value();
	return ( yule_pro_is_popular_section_enable( $control ) && 'page' == $content_type );
}

/**
 * Check if popular content type is post.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_popular_section_content_post( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[popular_content_type]' )->value();
	return ( yule_pro_is_popular_section_enable( $control ) && 'post' == $content_type );
}

/**
 * Check if popular content type is product.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_popular_section_content_product( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[popular_content_type]' )->value();
	return ( yule_pro_is_popular_section_enable( $control ) && 'product' == $content_type );
}

/**
 * Check if popular content type is not demo.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_popular_section_content_not_demo( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[popular_content_type]' )->value();
	return ( yule_pro_is_popular_section_enable( $control ) && 'demo' !== $content_type );
}

/**
 * Check if latest is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[latest_section_enable]' )->value() );
}

/**
 * Check if latest content type is post.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_content_post( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[latest_content_type]' )->value();
	return ( yule_pro_is_latest_section_enable( $control ) && 'post' == $content_type );
}

/**
 * Check if latest content type is product.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_content_product( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[latest_content_type]' )->value();
	return ( yule_pro_is_latest_section_enable( $control ) && 'product' == $content_type );
}

/**
 * Check if latest content type is category.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_content_category( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[latest_content_type]' )->value();
	return ( yule_pro_is_latest_section_enable( $control ) && 'category' == $content_type );
}

/**
 * Check if latest content type is product category.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_content_product_category( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[latest_content_type]' )->value();
	return ( yule_pro_is_latest_section_enable( $control ) && 'product-category' == $content_type );
}

/**
 * Check if latest count enable.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_latest_section_count_enable( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[latest_content_type]' )->value();
	return ( yule_pro_is_latest_section_enable( $control ) && ( 'demo' !== $content_type ) );
}

/**
 * Check if service is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service content type is post.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_service_section_content_post( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[service_content_type]' )->value();
	return ( yule_pro_is_service_section_enable( $control ) && 'post' == $content_type );
}

/**
 * Check if service content type is page.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_service_section_content_page( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[service_content_type]' )->value();
	return ( yule_pro_is_service_section_enable( $control ) && 'page' == $content_type );
}

/**
 * Check if service content type is custom.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_service_section_content_custom( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[service_content_type]' )->value();
	return ( yule_pro_is_service_section_enable( $control ) && 'custom' == $content_type );
}

/**
 * Check if featured is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured content type is post.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_featured_section_content_post( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[featured_content_type]' )->value();
	return ( yule_pro_is_featured_section_enable( $control ) && 'post' == $content_type );
}

/**
 * Check if featured content type is page.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_featured_section_content_page( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[featured_content_type]' )->value();
	return ( yule_pro_is_featured_section_enable( $control ) && 'page' == $content_type );
}

/**
 * Check if featured content type is product.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_featured_section_content_product( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[featured_content_type]' )->value();
	return ( yule_pro_is_featured_section_enable( $control ) && 'product' == $content_type );
}

/**
 * Check if cta is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta content type is post.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_cta_section_content_post( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[cta_content_type]' )->value();
	return ( yule_pro_is_cta_section_enable( $control ) && 'post' == $content_type );
}

/**
 * Check if cta content type is page.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_cta_section_content_page( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[cta_content_type]' )->value();
	return ( yule_pro_is_cta_section_enable( $control ) && 'page' == $content_type );
}

/**
 * Check if cta content type is custom.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_cta_section_content_custom( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[cta_content_type]' )->value();
	return ( yule_pro_is_cta_section_enable( $control ) && 'custom' == $content_type );
}

/**
 * Check if cta content type is not demo.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_cta_section_content_not_demo( $control ) {
	$content_type = $control->manager->get_setting( 'yule_pro_theme_options[cta_content_type]' )->value();
	return ( yule_pro_is_cta_section_enable( $control ) && 'demo' !== $content_type );
}

/**
 * Check if subscription is enabled.
 *
 * @since Yule Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_pro_theme_options[subscription_section_enable]' )->value() );
}