<?php
/**
 * Yule Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function yule_pro_customize_register( $wp_customize ) {
	$options = yule_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'yule_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'yule_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'yule-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'yule_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'yule_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'yule-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'yule_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'yule_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'yule-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'yule-pro' ),
			'show-all'     => esc_html__( 'Show All', 'yule-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'yule-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'yule-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'yule-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'yule-pro' ),
			)
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'yule_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'yule_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'yule-pro' ),
		'choices'  => array(
			'default'	=> esc_html__( 'Default', 'yule-pro' ),
			'blue'		=> esc_html__( 'Blue', 'yule-pro' ),
			'bluegem'	=> esc_html__( 'Blue Gem', 'yule-pro' ),
			'darkpink'  => esc_html__( 'Dark Pink', 'yule-pro' ),
			'green'   	=> esc_html__( 'Green', 'yule-pro' ),
			'orange'   	=> esc_html__( 'Orange', 'yule-pro' ),
			'purple'   	=> esc_html__( 'Purple', 'yule-pro' ),
			'red'   	=> esc_html__( 'Red', 'yule-pro' ),
			'salmon'   	=> esc_html__( 'Salmon', 'yule-pro' ),
			'steelblue' => esc_html__( 'Steel Blue', 'yule-pro' ),
			'yellow' 	=> esc_html__( 'Yellow', 'yule-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'yule-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'yule_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'yule_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'yule_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','yule-pro' ),
	    'description'=> esc_html__( 'Yule Pro Theme Options.', 'yule-pro' ),
	    'priority'   => 150,
	) );

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'yule_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','yule-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'yule-pro' ),
	    'priority'   => 140,
	) );

	// load top bar option
	require get_template_directory() . '/inc/customizer/sections/top-bar.php';

	// load popular option
	require get_template_directory() . '/inc/customizer/sections/popular.php';

	// load latest option
	require get_template_directory() . '/inc/customizer/sections/latest.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	// load featured option
	require get_template_directory() . '/inc/customizer/sections/featured.php';

	// load call to action option
	require get_template_directory() . '/inc/customizer/sections/cta.php';

	// load subscription option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';

}
add_action( 'customize_register', 'yule_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function yule_pro_customize_preview_js() {
	wp_enqueue_script( 'yule-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . yule_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'yule_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function yule_pro_customize_control_js() {
	// Choose from select jquery.
	wp_enqueue_script( 'yule-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls.js', array(), '1.0', true );
	$yule_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'yule-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'yule-pro-customize-controls', 'yule_pro_reset_data', $yule_pro_reset_data );


	wp_enqueue_style( 'customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'yule_pro_customize_control_js' );

if ( !function_exists( 'yule_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Yule Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function yule_pro_reset_options() {
		$options = yule_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'yule_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'yule_pro_reset_options' );
