<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 * @return array An array of default values
 */

function yule_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$yule_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#e35253',
		'header_tagline_color'			=> '#e35253',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme'					=> 'default',
		'colorscheme_hue'				=> '#000',

		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'		        => esc_html__( 'Read More', 'yule-pro' ),
		
		// breadcrumb options
		'breadcrumb_enable'         	=> true,
		'breadcrumb_separator'         	=> '/',

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'                => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Theme Author and URL', 'yule-pro' ), '[the-year]', '<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>' ),
		'scroll_top_visible'        	=> true,
		'footer_widget_width'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'yule-pro' ),
		'archive_col' 					=> 'col-3',
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_tags'						=> false,
		'hide_comments'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		// Front Page Sections
		// Top Bar
		'top_bar_enable'				=> true,
		'top_bar_contact_title'			=> esc_html__( 'Customer Support', 'yule-pro' ),
		'top_bar_contact_phone'			=> esc_html__( '+ 00 000 0000', 'yule-pro' ),
		'top_bar_cart_enable'			=> true,
		'top_bar_search_enable'			=> true,

		// Popular section
		'popular_section_enable'		=> true,
		'popular_content_type'			=> 'demo',
		'popular_btn_label'				=> esc_html__( 'Shop Now', 'yule-pro' ),

		// Latest section
		'latest_section_enable'			=> true,
		'latest_title'					=> esc_html__( 'Latest Products', 'yule-pro' ),
		'latest_content_type'			=> 'demo',
		'latest_count'					=> 6,
		'latest_btn_label'				=> esc_html__( 'View All Products', 'yule-pro' ),

		// Service section
		'service_section_enable'		=> true,
		'service_content_type'			=> 'demo',
		'service_title'					=> esc_html__( 'Service Title', 'yule-pro' ),
		'service_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit donec dolor neque id viverra eget, dictum a sem.', 'yule-pro' ),

		// Featured section
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'demo',
		'featured_count'				=> 2,

		// Call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'demo',
		'cta_title'						=> esc_html__( 'It&#39;s call to action', 'yule-pro' ),
		'cta_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris vestibulum sem a purus luctus, sed ullamcorper tortor tempor. Fusce tortor est, tristique molestie ligula ac, rhoncus tincidunt mi.', 'yule-pro' ),
		'cta_image'						=> get_template_directory_uri() . '/assets/uploads/call-to-action.jpg',
		'cta_btn_label'					=> esc_html__( 'Know more', 'yule-pro' ),

		// Subscription section
		'subscription_section_enable'	=> true,
		'subscription_title'			=> esc_html__( 'Subscribe today', 'yule-pro' ),

	);

	$output = apply_filters( 'yule_pro_default_theme_options', $yule_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}