<?php
/**
 * Top Bar options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add top bar section
$wp_customize->add_section( 'yule_pro_top_bar_section', array(
	'title'             => esc_html__( 'Top Bar','yule-pro' ),
	'description'       => esc_html__( 'Top Bar options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// top bar enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[top_bar_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['top_bar_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[top_bar_enable]', array(
	'label'             => esc_html__( 'Top Bar Enable', 'yule-pro' ),
	'section'           => 'yule_pro_top_bar_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// Contact title setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[top_bar_contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['top_bar_contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[top_bar_contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'yule-pro' ),
	'section'        	=> 'yule_pro_top_bar_section',
	'active_callback' 	=> 'yule_pro_is_top_bar_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[top_bar_contact_title]', array(
		'selector'            => '#top-navigation .contact-info ul li span',
		'settings'            => 'yule_pro_theme_options[top_bar_contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_top_bar_contact_title_partial',
    ) );
}

// contact phone repeater control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[top_bar_contact_phone]', array(
	'default' 			=> $options['top_bar_contact_phone'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Yule_Pro_Multi_Input_Custom_Control( $wp_customize, 'yule_pro_theme_options[top_bar_contact_phone]', array(
	'label'             => esc_html__( 'Phone No', 'yule-pro' ),
	'button_text'       => esc_html__( 'Add Phone No.', 'yule-pro' ),
	'section'           => 'yule_pro_top_bar_section',
	'active_callback' 	=> 'yule_pro_is_top_bar_enable',
) ) );

// top bar cart enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[top_bar_cart_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['top_bar_cart_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[top_bar_cart_enable]', array(
	'label'             => esc_html__( 'Cart Detail Enable', 'yule-pro' ),
	'section'           => 'yule_pro_top_bar_section',
	'on_off_label' 		=> yule_pro_switch_options(),
	'active_callback' 	=> 'yule_pro_is_top_bar_enable',
) ) );

// top bar search enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[top_bar_search_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['top_bar_search_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[top_bar_search_enable]', array(
	'label'             => esc_html__( 'Search Enable', 'yule-pro' ),
	'section'           => 'yule_pro_top_bar_section',
	'on_off_label' 		=> yule_pro_switch_options(),
	'active_callback' 	=> 'yule_pro_is_top_bar_enable',
) ) );