<?php
/**
 * Call to action section
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */
if ( ! function_exists( 'yule_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Yule Pro 1.0.0
    */
    function yule_pro_add_cta_section() {
    	$options = yule_pro_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'yule_pro_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'yule_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        yule_pro_render_cta_section( $section_details );
    }
endif;
add_action( 'yule_pro_primary_content', 'yule_pro_add_cta_section', 50 );

if ( ! function_exists( 'yule_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Yule Pro 1.0.0
    * @param array $input cta section details.
    */
    function yule_pro_get_cta_section_details( $input ) {
        $options = yule_pro_get_theme_options();

        // Content type.
        $cta_content_type  = $options['cta_content_type'];
        $content = array();
        switch ( $cta_content_type ) {
            case 'demo':
                $demo['title']      = esc_html__( 'It&#39;s call to action', 'yule-pro' );
                $demo['excerpt']    = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris vestibulum sem a purus luctus, sed ullamcorper tortor tempor. Fusce tortor est, tristique molestie ligula ac, rhoncus tincidunt mi.', 'yule-pro' );
                $demo['image']		= get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
                $demo['url']		= '#';

                // Push to the main array.
                array_push( $content, $demo );
            break;

            case 'custom':
                $custom['title']      = ! empty( $options['cta_title'] ) ? $options['cta_title'] : ''; 
                $custom['excerpt']    = ! empty( $options['cta_description'] ) ? $options['cta_description'] : '';
                $custom['image']      = ! empty( $options['cta_image'] ) ? $options['cta_image'] : '';
                $custom['url']        = ! empty( $options['cta_link'] ) ? $options['cta_link'] : '#';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;


            default:
            break;
        }

        if ( in_array( $cta_content_type, array( 'page', 'post' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']     	= get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = yule_pro_trim_content( 25 );
                    $page_post['url']   	= get_the_permalink();
                    $page_post['image']		= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'yule_pro_filter_cta_section_details', 'yule_pro_get_cta_section_details' );


if ( ! function_exists( 'yule_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Yule Pro 1.0.0
   *
   */
   function yule_pro_render_cta_section( $content_details = array() ) {
        $options = yule_pro_get_theme_options();
        $btn_label = ! empty( $options['cta_btn_label'] ) ? $options['cta_btn_label'] : esc_html__( 'Know More', 'yule-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
        	<div id="call-to-action" class="relative">
                <div class="wrapper">
                    <article <?php echo ! empty( $content['image'] ) ? 'class="has-featured-image"' : ''; ?>>
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; 

                            if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                </div><!-- .section-content -->
                            <?php endif; ?>

                            <div class="more-link">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-default"><?php echo esc_html( $btn_label ); ?></a>
                            </div><!-- .more-link -->
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #call-to-action -->
        <?php endforeach;
    }
endif;