<?php
/**
 * Featured section
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */
if ( ! function_exists( 'yule_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Yule Pro 1.0.0
    */
    function yule_pro_add_featured_section() {
    	$options = yule_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'yule_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'yule_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        yule_pro_render_featured_section( $section_details );
    }
endif;
add_action( 'yule_pro_primary_content', 'yule_pro_add_featured_section', 40 );

if ( ! function_exists( 'yule_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Yule Pro 1.0.0
    * @param array $input featured section details.
    */
    function yule_pro_get_featured_section_details( $input ) {
        $options = yule_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 2;
        $content = array();
        switch ( $featured_content_type ) {
            case 'demo':
                for ( $i = 1; $i <= 2; $i++ ) :
                    $demo['title']      = esc_html__( 'It&#39;s Simple in Design', 'yule-pro' );
                    $demo['price']		= sprintf( esc_html__( '%1$s150%2$s', 'yule-pro' ), '$<ins>', '</ins>' );
                    $demo['excerpt']    = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec dolor neque, ultrices cursus facilisis ut, finibus ut leo. Nunc vitae augue eget eros tristique euismod. Integer nunc lacus, ornare id viverra eget, dictum a sem. Fusce tincidunt ullamcorper...', 'yule-pro' );
                    $demo['image']		= get_template_directory_uri() . '/assets/uploads/featured-product-0' . $i . '.jpg';
                    $demo['url']		= '#';

                    // Push to the main array.
                    array_push( $content, $demo );
                endfor;
            break;

            case 'post':
                $post_ids = ! empty( $options['featured_content_post'] ) ? $options['featured_content_post'] : array();

                if ( empty( $post_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => count( $post_ids ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'product':
                $post_ids = ! empty( $options['featured_content_product'] ) ? $options['featured_content_product'] : array();

                if ( empty( $post_ids ) ) {
                    return $input;
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                   
            break;

            default:
            break;
        }

        if ( $featured_content_type !== 'demo' ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']     	= get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = get_the_excerpt();
                    $page_post['url']   	= get_the_permalink();
                    $page_post['image']		= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';
                    if ( class_exists( 'WooCommerce' ) && in_array( $featured_content_type, array( 'product' ) ) ):
                    	$product = new WC_Product( get_the_id() );
                    	$page_post['price'] = $product->get_price_html();
                	endif;

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'yule_pro_filter_featured_section_details', 'yule_pro_get_featured_section_details' );


if ( ! function_exists( 'yule_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Yule Pro 1.0.0
   *
   */
   function yule_pro_render_featured_section( $content_details = array() ) {
        $options = yule_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
    	<div id="featured-product" class="relative page-section">
            <div class="wrapper">
                <?php foreach ( $content_details as $content ) : ?>
                    <article <?php echo ! empty( $content['image'] ) ? 'class="has-featured-image"' : ''; ?>>
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <?php if ( in_array( $featured_content_type, array( 'demo', 'product' ) ) ) : ?>
                                <span class="price">
                                    <?php echo wp_kses_post( $content['price'] ); ?>
                                </span>
                            <?php endif; ?>

                            <div class="separator"></div>

                            <div class="entry-content">
                                <?php echo wp_kses_post( $content['excerpt'] ); ?>
                            </div><!-- .entry-content -->

                            <?php if ( class_exists( 'WooCommerce' ) && in_array( $featured_content_type, array( 'product' ) ) ) : ?>
                                <a rel="nofollow" href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" data-quantity="1" data-product_id="<?php echo absint( $content['id'] ) ?>" data-product_sku="" class="btn btn-default button product_type_simple add_to_cart_button ajax_add_to_cart"><?php esc_html_e( 'Add to cart', 'yule-pro' ); ?></a>
                            <?php elseif ( 'demo' == $featured_content_type ) : ?>
                                <a href="#" class="btn btn-default add_to_cart_button ajax_add_to_cart"><?php esc_html_e( 'Add to cart', 'yule-pro' ); ?></a>
                            <?php endif; ?>

                        </div><!-- .entry-container -->
                    </article>
            <?php endforeach; ?>
            </div><!-- .wrapper -->
        </div><!-- #featured-product -->
    <?php
    }
endif;