<?php
/**
 * Yule Pro basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

$options = yule_pro_get_theme_options();


if ( ! function_exists( 'yule_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Yule Pro 1.0.0
	 */
	function yule_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'yule_pro_doctype', 'yule_pro_doctype', 10 );


if ( ! function_exists( 'yule_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'yule_pro_before_wp_head', 'yule_pro_head', 10 );

if ( ! function_exists( 'yule_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'yule-pro' ); ?></a>

		<?php
	}
endif;

add_action( 'yule_pro_page_start_action', 'yule_pro_page_start', 10 );

if ( ! function_exists( 'yule_pro_top_bar' ) ) :
	/**
	 * top bar html codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_top_bar() {
		$options = yule_pro_get_theme_options();
		if ( false === $options['top_bar_enable'] ) {
			return;
		}
		$label = ! empty( $options['top_bar_contact_title'] ) ? $options['top_bar_contact_title'] : '';
		$phone = ! empty( $options['top_bar_contact_phone'] ) ? explode( '|', $options['top_bar_contact_phone'] ) : array();
		?>
		<div id="top-navigation" class="relative col-2">
            <div class="wrapper">
            	<?php if ( ! empty( $label ) || ! empty( $phone ) ) : ?>
	                <div class="contact-info">
	                    <ul>
	                        <li>
	                        	<?php if ( ! empty( $label ) ) : ?>
			                        <span><?php echo esc_html( $label ); ?></span>: 
			                    <?php endif; 
			                    if ( ! empty( $phone ) ) :
		                        	echo esc_html( implode( ', ', $phone ) ); 
		                        endif; ?>
	                        </li>
	                    </ul>
	                </div>
	            <?php endif; ?>

                <div class="top-menu">
                <?php 
                $cart = '';
                if ( class_exists( 'WooCommerce' ) && true === $options['top_bar_cart_enable'] ) :
            		$count = WC()->cart->get_cart_contents_count();
                    $cart = '<li><a href="' . esc_url( wc_get_cart_url() ) . '"><span class="count">' . absint( $count ) . '</span>' . esc_html__( 'Cart', 'yule-pro' ) . '</a></li>';
                endif;

                $search = '';
                if ( true === $options['top_bar_search_enable'] ) :
                	$search = '<li class="search-menu"><a href="#"><span class="screen-reader-text">' . esc_html__( 'search' , 'yule-pro' ) . '</span>'; 
                	$search .= yule_pro_get_svg( array( 'icon' => 'search' ) );
                	$search .= yule_pro_get_svg( array( 'icon' => 'close' ) );
                    $search .= '</a><div id="search">';
                    $search .= get_search_form( $echo = false );
                    $search .= '</div><!-- #search --></li>';
            	endif;

            	$defaults = array(
            		'theme_location' => 'topbar',
            		'container' => false,
            		'menu_class' => 'menu',
            		'fallback_cb' => 'yule_pro_top_menu_fallback_cb',
            		'items_wrap' => '<ul id="%1$s" class="%2$s">' . $cart . '%3$s' . $search . '</ul>',
            		'depth' => 1,
            	);
            
            	wp_nav_menu( $defaults );
                ?>
                </div><!-- .top-menu -->
            </div><!-- .wrapper -->
        </div><!-- #top-navigation -->

		<?php
	}
endif;

add_action( 'yule_pro_page_start_action', 'yule_pro_top_bar', 20 );

if ( ! function_exists( 'yule_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'yule_pro_page_end_action', 'yule_pro_page_end', 10 );

if ( ! function_exists( 'yule_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_header_start() {
		?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'yule_pro_header_action', 'yule_pro_header_start', 10 );

if ( ! function_exists( 'yule_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_site_branding() {
		$options  = yule_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php 
			if ( 'show-all' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) { 
				if ( has_custom_logo() ) : ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php endif; 
			} ?>

			<div id="site-details">
				<?php if( 'show-all' === $header_txt_logo_extra  || 'title-only' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra ) { ?>
					<?php if ( yule_pro_is_latest_posts() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php endif; ?>
				<?php } 
				if ( 'show-all' === $header_txt_logo_extra  || 'tagline-only' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; 
				}?>
			</div><!-- #site-detials -->
			
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'yule_pro_header_action', 'yule_pro_site_branding', 20 );

if ( ! function_exists( 'yule_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_site_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<span class="menu-label"><?php esc_html_e( 'Menu', 'yule-pro' ); ?></span>
				<?php
				echo yule_pro_get_svg( array( 'icon' => 'menu' ) );
				echo yule_pro_get_svg( array( 'icon' => 'close' ) );
				?>					
			</button>
			<?php wp_nav_menu( array( 
				'fallback_cb'=>'yule_pro_menu_fallback_cb', 
				'theme_location' => 'primary', 
				'menu_id' => 'primary-menu',
				'menu_class' => 'menu nav-menu', 
			) ); ?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'yule_pro_header_action', 'yule_pro_site_navigation', 30 );


if ( ! function_exists( 'yule_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'yule_pro_header_action', 'yule_pro_header_end', 50 );

if ( ! function_exists( 'yule_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'yule_pro_content_start_action', 'yule_pro_content_start', 10 );

if ( ! function_exists( 'yule_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'yule_pro_content_end_action', 'yule_pro_content_end', 10 );

if ( ! function_exists( 'yule_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'yule_pro_footer', 'yule_pro_footer_start', 10 );

if ( ! function_exists( 'yule_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_footer_site_info() {
		$options = yule_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info">
			<div class="wrapper <?php echo has_nav_menu( 'social' ) ? 'col-2' : 'col-1'; ?>">
                <div class="footer-copyright">
					<?php 
					echo yule_pro_santize_allow_tag( $copyright_text ); 
					if ( function_exists( 'the_privacy_policy_link' ) ) {
					    the_privacy_policy_link( ' | ' );
					}
					?>
				</div>
				<?php if ( has_nav_menu( 'social' ) ) : ?>
					<div class="social-menu">
						<?php
						$defaults = array(
							'theme_location' => 'social',
							'container' => false,
							'menu_class' => 'social-icons',
							'fallback_cb' => false,
							'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
						);
					
						wp_nav_menu( $defaults ); 
						?>
					</div>
				<?php endif; ?>
			</div><!-- .wrapper --> 
		</div><!-- .site-info -->
		<?php
	}
endif;
add_action( 'yule_pro_footer', 'yule_pro_footer_site_info', 40 );

if ( ! function_exists( 'yule_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_footer_scroll_to_top() {
		$options  = yule_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo yule_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'yule_pro_footer', 'yule_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'yule_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_footer_end() {
		?>
		</footer>
		<?php
	}
endif;
add_action( 'yule_pro_footer', 'yule_pro_footer_end', 100 );

if ( ! function_exists( 'yule_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_loader() {
		$options = yule_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
				<div class="loader-container">
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            </div>
            </div>
		<?php }
	}
endif;
add_action( 'yule_pro_before_header', 'yule_pro_loader', 10 );


if ( ! function_exists( 'yule_pro_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since Yule Pro 1.0.0
	 */
	function yule_pro_add_breadcrumb() {
		$options = yule_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( yule_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list">
			<div class="wrapper">';
				/**
				 * yule_pro_simple_breadcrumb hook
				 *
				 * @hooked yule_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'yule_pro_simple_breadcrumb' );
		echo '</div><!-- .container -->
			</div><!-- #breadcrumb-list -->';
		return;
	}

endif;
add_action( 'yule_pro_add_breadcrumb_action', 'yule_pro_add_breadcrumb' );

if ( ! function_exists( 'yule_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Yule Pro 1.0.0
	 *
	 */
	function yule_pro_infinite_loader_spinner() { 
		global $post;
		$options = yule_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( $post ) > 0 ) {
				echo '<div class="blog-loader">' . yule_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'yule_pro_infinite_loader_spinner_action', 'yule_pro_infinite_loader_spinner', 10 );
