<?php
/**
 * Yule Pro WooCoommerce compatibility hooks.
 *
 * This is the template that includes all WooCoommerce hooks to make the theme compatible with WooCommerce.
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function yule_pro_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'yule_pro_woocommerce_setup' );

if ( ! function_exists( 'yule_pro_woocommerce_product_columns_wrapper' ) ) {
	/**
	 * Product columns wrapper.
	 *
	 * @return  void
	 */
	function yule_pro_woocommerce_product_columns_wrapper() {
		echo '<div id="page-header" class="relative">
		        <div class="wrapper">
		            <header class="page-header">
		                <h2 class="page-title">';
		                	if ( is_shop() )
			                	woocommerce_page_title();
			                else
			                	the_title();
        echo  			'</h2>
		            </header><!-- .page-header -->
		        </div><!-- .wrapper -->
		    </div><!--#header-image -->';
	    /**
		 * yule_pro_add_breadcrumb_action hook
		 *
		 * @hooked yule_pro_add_breadcrumb -  10
		 *
		 */
		do_action( 'yule_pro_add_breadcrumb_action' );

		echo '<div id="inner-content-wrapper" class="page-section">
	    			<div class="wrapper">';
	}
}
add_action( 'woocommerce_before_main_content', 'yule_pro_woocommerce_product_columns_wrapper', 5 );

if ( ! function_exists( 'yule_pro_woocommerce_product_columns_wrapper_close' ) ) {
	/**
	 * Product columns wrapper close.
	 *
	 * @return  void
	 */
	function yule_pro_woocommerce_product_columns_wrapper_close() {
		echo '</div>
			</div>';
	}
}
add_action( 'woocommerce_after_main_content', 'yule_pro_woocommerce_product_columns_wrapper_close', 20 );

/**
 * Remove default sidebar position.
 */
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );

add_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 20 );

add_filter( 'woocommerce_show_page_title', 'yule_pro_show_page_title' );
if ( ! function_exists( 'yule_pro_show_page_title' ) ) {
	function yule_pro_show_page_title() {
		return false; // 3 products per row
	}
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'yule_pro_loop_columns');

if ( ! function_exists( 'yule_pro_loop_columns' ) ) {
	function yule_pro_loop_columns() {
		return 3; // 3 products per row
	}
}

add_action( 'woocommerce_after_main_content', 'yule_pro_shop_sidebar', 15 );
if ( ! function_exists( 'yule_pro_shop_sidebar' ) ) {
	function yule_pro_shop_sidebar() {
		if ( yule_pro_is_sidebar_enable() ) {
			get_sidebar();
		}
	}
}

add_filter( 'get_product_search_form', 'yule_pro_product_search' );
if ( ! function_exists( 'yule_pro_product_search' ) ) { 
	function yule_pro_product_search() { ?>
		<form role="search" method="get" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
			<label class="screen-reader-text" for="woocommerce-product-search-field-<?php echo isset( $index ) ? absint( $index ) : 0; ?>"><?php esc_html_e( 'Search for:', 'yule-pro' ); ?></label>
			<input type="search" id="woocommerce-product-search-field-<?php echo isset( $index ) ? absint( $index ) : 0; ?>" class="search-field" placeholder="<?php echo esc_attr__( 'Search products&hellip;', 'yule-pro' ); ?>" value="<?php echo get_search_query(); ?>" name="s" />
			<input type="hidden" name="post_type" value="product" />
			<button type="submit" class="search-submit"><?php echo yule_pro_get_svg( array( 'icon' => 'search' ) ); ?><span class="screen-reader-text"><?php echo esc_html_x( 'Search', 'submit button', 'yule-pro' ); ?></span></button>
		</form>
	<?php }
}